(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      6762,        214]*)
(*NotebookOutlinePosition[      7926,        254]*)
(*  CellTagsIndexPosition[      7839,        248]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[{
  "Cartesian Product\n",
  StyleBox["Construct cartesian product of n finite sets.",
    FontSize->14,
    FontWeight->"Bold"],
  StyleBox["\n",
    FontSize->18],
  StyleBox["\[Copyright] 2005 Cornelius Nevrinceanu - All Copywrongs Reversed \
- Omnia jura vindicabuntur",
    FontSize->6,
    FontWeight->"Plain",
    FontVariations->{"CompatibilityType"->"Superscript"}]
}], "Title",
  CellDingbat->None,
  CellMargins->{{2, 4}, {Inherited, Inherited}},
  CellLabelMargins->{{2, Inherited}, {Inherited, Inherited}},
  TextAlignment->Center,
  TextJustification->0,
  AspectRatioFixed->False,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Divide each difficulty into as many parts as is feasible and \
necessary to resolve it.\n",
    FontFamily->"American Typewriter",
    FontSize->12,
    FontWeight->"Bold"],
  StyleBox["Rene desCartes",
    FontFamily->"American Typewriter",
    FontSize->10]
}], "SmallText",
  TextAlignment->Right,
  TextJustification->0],

Cell[" Cart -- usage", "Subsection"],

Cell[BoxData[
    \(\(Cart::usage\  = \ "\<Cart[set0, set1, ... setn]   Example: Cart[{1, \
2, 3}, {a, b}]\n   Construct the Cartesian product of a number of finite \
sets, represented as lists.\nCart[n][set]                 Example: \
Cart[2][{1, 2, 3}]\n   Construct the Cartesian product of power n of one set.\
\>";\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(?? Cart\)], "Input"],

Cell[BoxData[
    \("Cart[set0, set1, ... setn]   Example: Cart[{1, 2, 3}, {a, b}]\n   \
Construct the Cartesian product of a number of finite sets, represented as \
lists.\nCart[n][set]                 Example: Cart[2][{1, 2, 3}]\n   \
Construct the Cartesian product of power n of one set."\)], "Print",
  CellTags->"Info3360488125-4961139"]
}, Open  ]],

Cell["1. Base Case -- Zero and one Set", "Section",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \(\(\(Cart[]\  = \ {{}};\)\(\ \ \)\)\)], "Input"],

Cell[" Note", "Text",
  CellMargins->{{227.375, Inherited}, {Inherited, Inherited}}],

Cell["\<\
 This rule is peculiar, but it may be required in order to make be \
able to map 0-ary functions over a cartesian power.\
\>", "SmallText",
  CellMargins->{{227.375, Inherited}, {Inherited, Inherited}}],

Cell[CellGroupData[{

Cell[BoxData[
    \(Map[
      Function[arg, \ 
        Apply[g[0], \ arg]], \ \(Cart[0]\)[{a, \ b, \ c}]]\)], "Input",
  CellMargins->{{227.375, Inherited}, {Inherited, Inherited}}],

Cell[BoxData[
    \(\(Cart[0]\)[\(g[0]\)[a, b, c]]\)], "Output"]
}, Open  ]],

Cell[" vs.", "SmallText",
  CellMargins->{{229.312, Inherited}, {Inherited, Inherited}}],

Cell[CellGroupData[{

Cell[BoxData[
    \(Map[Function[arg, \ Apply[g[0], \ arg]], \ {}]\)], "Input",
  CellMargins->{{227.375, Inherited}, {Inherited, Inherited}}],

Cell[BoxData[
    \({}\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(Cart[set_]\  := \ MakeUnitSets[set]\)], "Input"],

Cell[BoxData[
    \(\(MakeUnitSets[{}]\  = \ {};\)\)], "Input",
  CellMargins->{{60.5, Inherited}, {Inherited, Inherited}}],

Cell[BoxData[
    \(MakeUnitSets[{first_, \ rest___}]\  := \[IndentingNewLine]Prepend[
        MakeUnitSets[{rest}], \ {first}]\)], "Input",
  CellMargins->{{60.5, Inherited}, {Inherited, Inherited}}],

Cell["2. General Case -- Several Sets", "Section",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \(Cart[firstSet_, \ restSets___]\  := \[IndentingNewLine]PrependToAll[
        Cart[restSets], \ firstSet]\)], "Input",
  CellLabel->"In[78]:="],

Cell[BoxData[
    \(\(PrependToAll[{}, \ set_]\  = \ {};\)\)], "Input",
  CellMargins->{{60, Inherited}, {Inherited, Inherited}}],

Cell[BoxData[
    \(PrependToAll[{firstSet_, \ restSets___}, \ 
        set_]\  := \[IndentingNewLine]Join[\ PrependSet[firstSet, \ set], 
        PrependToAll[{restSets}, \ set]]\)], "Input",
  CellMargins->{{60, Inherited}, {Inherited, Inherited}}],

Cell[BoxData[
    \(\(\(\[IndentingNewLine]\)\(PrependSet[
          to_, \ {}\ ]\  = \ {};\)\)\)], "Input",
  CellMargins->{{86.5, Inherited}, {Inherited, Inherited}}],

Cell[BoxData[
    \(PrependSet[
        to_, \ {firstEl_, \ restEls___}]\  := \[IndentingNewLine]Prepend[
        PrependSet[to, \ {restEls}], \ Append[to, \ firstEl]]\)], "Input",
  CellMargins->{{86.5, Inherited}, {Inherited, Inherited}}],

Cell["3. Power of a set", "Section",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \(\(Cart[n_]\)[set_]\  := \ 
      Apply[Cart, \ IterateSet[set, \ n]]\)], "Input"],

Cell[BoxData[
    \(\(IterateSet[set_, \ 0]\  = \ {};\)\)], "Input"],

Cell[BoxData[
    \(IterateSet[set_, \ n_]\  := \[IndentingNewLine]Prepend[
        IterateSet[set, \ n\  - \ 1], \ set]\)], "Input"],

Cell[TextData[{
  StyleBox["Entia praeter necessitatem non sunt multiplicanda.\n",
    FontFamily->"American Typewriter",
    FontSize->12,
    FontWeight->"Bold"],
  StyleBox["William of Ockham",
    FontFamily->"American Typewriter",
    FontSize->12]
}], "SmallText",
  TextAlignment->Right,
  TextJustification->0]
},
FrontEndVersion->"5.2 for Macintosh",
ScreenRectangle->{{0, 1020}, {0, 746}},
WindowToolbars->{"RulerBar", "EditBar"},
CellGrouping->Manual,
WindowSize->{973, 704},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowSelection->True,
ShowCellLabel->False,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
Magnification->1.5,
StyleDefinitions -> "TutorialBook.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Info3360488125-4961139"->{
    Cell[3195, 99, 343, 5, 134, "Print",
      CellTags->"Info3360488125-4961139"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Info3360488125-4961139", 7729, 241}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 642, 19, 178, "Title"],
Cell[2399, 72, 352, 11, 70, "SmallText"],
Cell[2754, 85, 36, 0, 61, "Subsection"],
Cell[2793, 87, 334, 5, 230, "Input"],

Cell[CellGroupData[{
Cell[3152, 96, 40, 1, 44, "Input"],
Cell[3195, 99, 343, 5, 134, "Print",
  CellTags->"Info3360488125-4961139"]
}, Open  ]],
Cell[3553, 107, 84, 1, 132, "Section"],
Cell[3640, 110, 67, 1, 44, "Input"],
Cell[3710, 113, 84, 1, 39, "Text"],
Cell[3797, 116, 212, 4, 62, "SmallText"],

Cell[CellGroupData[{
Cell[4034, 124, 182, 4, 75, "Input"],
Cell[4219, 130, 64, 1, 40, "Output"]
}, Open  ]],
Cell[4298, 134, 88, 1, 40, "SmallText"],

Cell[CellGroupData[{
Cell[4411, 139, 142, 2, 75, "Input"],
Cell[4556, 143, 36, 1, 40, "Output"]
}, Open  ]],
Cell[4607, 147, 68, 1, 44, "Input"],
Cell[4678, 150, 123, 2, 44, "Input"],
Cell[4804, 154, 200, 3, 75, "Input"],
Cell[5007, 159, 83, 1, 132, "Section"],
Cell[5093, 162, 162, 3, 75, "Input"],
Cell[5258, 167, 129, 2, 44, "Input"],
Cell[5390, 171, 250, 4, 106, "Input"],
Cell[5643, 177, 168, 3, 75, "Input"],
Cell[5814, 182, 240, 4, 106, "Input"],
Cell[6057, 188, 69, 1, 132, "Section"],
Cell[6129, 191, 101, 2, 44, "Input"],
Cell[6233, 195, 68, 1, 44, "Input"],
Cell[6304, 198, 133, 2, 75, "Input"],
Cell[6440, 202, 318, 10, 72, "SmallText"]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

