(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      7310,        279]*)
(*NotebookOutlinePosition[      8552,        325]*)
(*  CellTagsIndexPosition[      8404,        316]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[{
  StyleBox["Rose-Trees",
    FontWeight->"Bold"],
  "\n",
  StyleBox["All Copywrongs  Reversed  -- Cornelius Nevrinceanu,  2006 --  \
Omnia jura vindicabuntur",
    FontSize->5,
    FontWeight->"Plain",
    FontSlant->"Italic",
    FontVariations->{"CompatibilityType"->0}]
}], "Title",
  TextAlignment->Center,
  TextJustification->0,
  FontFamily->"Courier"],

Cell[TextData[StyleBox["Rhodo-Dendron: Lambert Meertens, 1987",
  FontFamily->"American Typewriter",
  FontSize->14,
  FontWeight->"Bold"]], "Text",
  TextAlignment->Right,
  TextJustification->0,
  FontSize->8],

Cell["1. Arboretum", "Section"],

Cell[BoxData[
    \(\(RTree[1]\  = \n\ \ Node[
          1, {Node[21, \ {}], \ Node[22, \ {}]}];\)\)], "Input",
  CellLabel->"In[227]:="],

Cell[BoxData[
    \(\(RTree[2]\  = \n
        Node[1, \n\t{\n\tNode[21, \ {}], \ \n\t
            Node[22, \n\t\t{Node[221, \ {}]}], \n\t
            Node[23, \n\t\t{\n\t\tNode[
                  231, \n\t\t\t{\n\t\t\tNode[2311, \ {}], \n\t\t\tNode[
                      2312, \ {}]\n\t\t\t}]\n\t\t}], \n\t
            Node[24, \ {}]\n\t}];\)\)], "Input",
  CellLabel->"In[228]:="],

Cell["2. Fathoms & Rods", "Section"],

Cell[BoxData[
    \(TSize[Node[x_, \ xts_]]\  := \n\t
      1\  + \ AddUp[Map[\ Size, \ xts]]\)], "Input",
  CellLabel->"In[229]:=",
  CellTags->"TSize"],

Cell[" Where", "Text",
  TextAlignment->Right,
  TextJustification->0],

Cell[BoxData[{
    \(\(AddUp[{}]\  := \ 0;\)\), "\n", 
    \(AddUp[lis_]\  := \ Apply[Plus, \ lis]\)}], "Input",
  CellLabel->"In[230]:="],

Cell[BoxData[
    \(THeight[Node[x_, \ xts_]]\  := \n\t
      1\  + \ MaxList[Map[THeight, \ xts]]\)], "Input",
  CellLabel->"In[232]:=",
  CellTags->"THeight"],

Cell[" Where", "Text",
  TextAlignment->Right,
  TextJustification->0],

Cell[BoxData[
    \(MaxList[{}]\ \  = \ 0; \ 
    MaxList[lis_]\  := \ Apply[Max, \ lis];\)], "Input",
  CellLabel->"In[233]:="],

Cell["3. Plumbing & Tallying", "Section"],

Cell[CellGroupData[{

Cell[BoxData[
    \({TSize[RTree[1]], \ THeight[RTree[1]]}\)], "Input",
  CellLabel->"In[234]:="],

Cell[BoxData[
    \({3, 2}\)], "Output",
  CellLabel->"Out[234]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\({TSize[RTree[2]], \ THeight[RTree[2]]}\)\(\ \)\)\)], "Input",
  CellLabel->"In[235]:="],

Cell[BoxData[
    \({9, 4}\)], "Output",
  CellLabel->"Out[235]="]
}, Open  ]],

Cell["4. Depth-First Order", "Section"],

Cell[BoxData[
    \(TDFirst[Node[x_, \ xts_]]\  := \n\t
      Prepend[JoinList[Map[TDFirst, \ xts]], \ x]\)], "Input",
  CellLabel->"In[303]:=",
  CellTags->"TDFirst"],

Cell["Where", "Text",
  TextAlignment->Right,
  TextJustification->0],

Cell[BoxData[
    \(JoinList[xss_]\  := \ Apply[Join, \ xss]\)], "Input",
  CellLabel->"In[304]:="],

Cell[" Examples", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \({TDFirst[RTree[1]], \ TDFirst[RTree[2]]}\)], "Input",
  CellLabel->"In[305]:="],

Cell[BoxData[
    \({{1, 21, 22}, {1, 21, 22, 221, 23, 231, 2311, 2312, 24}}\)], "Output",
  CellLabel->"Out[305]="]
}, Open  ]],

Cell["5. Breadth-First Order", "Section"],

Cell[" Note", "Subsection"],

Cell["\<\
 Unlike depth-first order, bredth-first order cannot be constructed \
from a breadth-first ordering of its sub-trees.\
\>", "Subsubsection"],

Cell[" Why?", "Text",
  TextAlignment->Right,
  TextJustification->0],

Cell[" We define then", "Subsubsection"],

Cell[BoxData[
    \(TBLevels[Node[x_, \ xts_]]\  := \n\t
      Prepend[Combine[Map[TBLevels, \ xts]], \n\t\t\t{x}]\)], "Input",
  CellLabel->"In[239]:="],

Cell[" Example", "Subsubsection",
  CellMargins->{{88.625, Inherited}, {Inherited, Inherited}}],

Cell[CellGroupData[{

Cell[BoxData[
    \(TBLevels[RTree[1]]\)], "Input",
  CellLabel->"In[240]:=",
  CellMargins->{{88.625, Inherited}, {Inherited, Inherited}}],

Cell[BoxData[
    \({{1}, {21, 22}}\)], "Output",
  CellLabel->"Out[240]="]
}, Open  ]],

Cell["...  for suitable Combine, and", "Text",
  TextAlignment->Right,
  TextJustification->0],

Cell["... find", "Subsubsection"],

Cell[BoxData[
    \(TBFirst[t_]\  := \ Join[TBLevels[t]]\)], "Input",
  CellLabel->"In[241]:=",
  CellTags->"TBFirst"],

Cell[" where", "Text",
  TextAlignment->Right,
  TextJustification->0],

Cell[BoxData[
    \(Combine[lis_]\  := \ Fold[Zip, \ {}, \ lis]\)], "Input",
  CellLabel->"In[242]:="],

Cell["and", "Text",
  TextAlignment->Right,
  TextJustification->0],

Cell[BoxData[{
    \(\(Zip[{}, \ yss_]\  := \ yss;\)\), "\n", 
    \(\(Zip[{xs_, \ xss___}, \ {}]\  := \ {xs, \ xss};\)\), "\n", 
    \(Zip[{xs_, \ xss___}, \ {ys_, \ yss___}]\  := \n\t
      Prepend[Zip[{xss}, \ {yss}], \ Join[xs, \ ys]]\)}], "Input",
  CellLabel->"In[243]:="],

Cell[" Examples", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TBFirst[RTree[1]]\)], "Input",
  CellLabel->"In[246]:="],

Cell[BoxData[
    \({{1}, {21, 22}}\)], "Output",
  CellLabel->"Out[246]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TBFirst[RTree[2]]\)], "Input",
  CellLabel->"In[247]:="],

Cell[BoxData[
    \({{1}, {21, 22, 23, 24}, {221, 231}, {2311, 2312}}\)], "Output",
  CellLabel->"Out[247]="]
}, Open  ]],

Cell[TextData[{
  StyleBox["The axe is laid unto the root of the trees.",
    FontFamily->"American Typewriter",
    FontSize->13,
    FontWeight->"Bold",
    FontColor->RGBColor[0.0153658, 0, 0.125841]],
  StyleBox["\nLuke iii. 9.",
    FontFamily->"American Typewriter",
    FontSize->13,
    FontColor->RGBColor[0.0153658, 0, 0.125841]]
}], "Text",
  TextAlignment->Right,
  TextJustification->0]
},
FrontEndVersion->"5.2 for Macintosh",
ScreenRectangle->{{0, 1020}, {0, 746}},
WindowToolbars->{"RulerBar", "EditBar"},
CellGrouping->Manual,
WindowSize->{989, 711},
WindowMargins->{{12, Automatic}, {Automatic, 0}},
ShowSelection->True,
ShowCellLabel->False,
ShowCellTags->True,
StyleDefinitions -> "TutorialBook.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "TSize"->{
    Cell[2945, 93, 153, 4, 94, "Input",
      CellTags->"TSize"]},
  "THeight"->{
    Cell[3315, 108, 160, 4, 94, "Input",
      CellTags->"THeight"]},
  "TDFirst"->{
    Cell[4188, 149, 167, 4, 94, "Input",
      CellTags->"TDFirst"]},
  "TBFirst"->{
    Cell[5807, 217, 118, 3, 63, "Input",
      CellTags->"TBFirst"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"TSize", 8057, 300},
  {"THeight", 8139, 303},
  {"TDFirst", 8224, 306},
  {"TBFirst", 8309, 309}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 376, 13, 129, "Title"],
Cell[2133, 66, 211, 6, 44, "Text"],
Cell[2347, 74, 31, 0, 132, "Section"],
Cell[2381, 76, 137, 3, 75, "Input"],
Cell[2521, 81, 382, 8, 509, "Input"],
Cell[2906, 91, 36, 0, 132, "Section"],
Cell[2945, 93, 153, 4, 94, "Input",
  CellTags->"TSize"],
Cell[3101, 99, 70, 2, 39, "Text"],
Cell[3174, 103, 138, 3, 75, "Input"],
Cell[3315, 108, 160, 4, 94, "Input",
  CellTags->"THeight"],
Cell[3478, 114, 70, 2, 39, "Text"],
Cell[3551, 118, 128, 3, 44, "Input"],
Cell[3682, 123, 41, 0, 132, "Section"],

Cell[CellGroupData[{
Cell[3748, 127, 97, 2, 44, "Input"],
Cell[3848, 131, 66, 2, 40, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3951, 138, 111, 2, 44, "Input"],
Cell[4065, 142, 66, 2, 40, "Output"]
}, Open  ]],
Cell[4146, 147, 39, 0, 132, "Section"],
Cell[4188, 149, 167, 4, 94, "Input",
  CellTags->"TDFirst"],
Cell[4358, 155, 69, 2, 39, "Text"],
Cell[4430, 159, 99, 2, 44, "Input"],
Cell[4532, 163, 34, 0, 53, "Subsubsection"],

Cell[CellGroupData[{
Cell[4591, 167, 99, 2, 44, "Input"],
Cell[4693, 171, 116, 2, 40, "Output"]
}, Open  ]],
Cell[4824, 176, 41, 0, 132, "Section"],
Cell[4868, 178, 27, 0, 61, "Subsection"],
Cell[4898, 180, 150, 3, 76, "Subsubsection"],
Cell[5051, 185, 69, 2, 39, "Text"],
Cell[5123, 189, 40, 0, 53, "Subsubsection"],
Cell[5166, 191, 153, 3, 106, "Input"],
Cell[5322, 196, 95, 1, 53, "Subsubsection"],

Cell[CellGroupData[{
Cell[5442, 201, 139, 3, 44, "Input"],
Cell[5584, 206, 75, 2, 40, "Output"]
}, Open  ]],
Cell[5674, 211, 94, 2, 39, "Text"],
Cell[5771, 215, 33, 0, 53, "Subsubsection"],
Cell[5807, 217, 118, 3, 63, "Input",
  CellTags->"TBFirst"],
Cell[5928, 222, 70, 2, 39, "Text"],
Cell[6001, 226, 102, 2, 44, "Input"],
Cell[6106, 230, 67, 2, 39, "Text"],
Cell[6176, 234, 278, 5, 137, "Input"],
Cell[6457, 241, 31, 0, 61, "Subsection"],

Cell[CellGroupData[{
Cell[6513, 245, 76, 2, 44, "Input"],
Cell[6592, 249, 75, 2, 40, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6704, 256, 76, 2, 44, "Input"],
Cell[6783, 260, 109, 2, 40, "Output"]
}, Open  ]],
Cell[6907, 265, 399, 12, 84, "Text"]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

